==> haskell-bower-json-1.0.0.1-108-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-HJLhc2RQV9rGPCEfV5gqfN
key: bower-json-1.0.0.1-HJLhc2RQV9rGPCEfV5gqfN
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: d49669995745941c476fefa75dfdd2b3
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-HJLhc2RQV9rGPCEfV5gqfN
depends:
    aeson-1.4.2.0-4xcoKSM2rCuFeYBdCYWLDU
    aeson-better-errors-0.9.1.0-E2snKfqX5ES9T7LkIq2k8Y base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-109-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-FgjI8A0xbPLCJRjmpMnNW7
key: bower-json-1.0.0.1-FgjI8A0xbPLCJRjmpMnNW7
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: 4bff773dc33ed6dc0f453ea317b65f93
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-FgjI8A0xbPLCJRjmpMnNW7
depends:
    aeson-1.4.3.0-AyEaiR0tyNR44JmKj60DSr
    aeson-better-errors-0.9.1.0-2SzPtnNLnBf2O5PAeTfV6Y base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
